@@ -38,6 +38,7 @@
 ****************************************************************************/
 
 #include "qline.h"
+
 #include "qdebug.h"
 #include "qdatastream.h"
 #include "qmath.h"
@@ -99,7 +100,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \fn bool QLine::isNull() const
 
-    Returns \c true if the line is not set up with valid start and end point;
+    Returns \c true if the line does not have distinct start and end points;
     otherwise returns \c false.
 */
 
@@ -347,7 +348,7 @@ QDataStream &operator>>(QDataStream &stream, QLine &line)
     function to determine whether the QLineF represents a valid line
     or a null line.
 
-    The intersect() function determines the IntersectType for this
+    The intersects() function determines the IntersectionType for this
     line and a given line, while the angleTo() function returns the
     angle between the lines. In addition, the unitVector() function
     returns a line that has the same starting point as this line, but
@@ -370,6 +371,18 @@ QDataStream &operator>>(QDataStream &stream, QLine &line)
 
 /*!
     \enum QLineF::IntersectType
+    \obsolete Use QLineF::IntersectionType instead.
+
+    \value NoIntersection
+           Lines do not intersect.
+    \value UnboundedIntersection
+           Lines intersect, but not within the range defined by their lengths.
+    \value BoundedIntersection
+           Lnes intersect within the range defined by their lengths.
+*/
+
+/*!
+    \typealias QLineF::IntersectionType
 
     Describes the intersection between two lines.
 
@@ -428,8 +441,14 @@ QDataStream &operator>>(QDataStream &stream, QLine &line)
 /*!
     \fn bool QLineF::isNull() const
 
-    Returns \c true if the line is not set up with valid start and end point;
-    otherwise returns \c false.
+    Returns \c true if the line does not have distinct start and end points;
+    otherwise returns \c false. The start and end points are considered distinct
+    if qFuzzyCompare() can distinguish them in at least one coordinate.
+
+    \note Due to the use of fuzzy comparison, isNull() may return \c true for
+    lines whose length() is not zero.
+
+    \sa qFuzzyCompare(), length()
 */
 
 /*!
@@ -512,10 +531,10 @@ QDataStream &operator>>(QDataStream &stream, QLine &line)
     Sets the length of the line to the given \a length. QLineF will
     move the end point - p2() - of the line to give the line its new length.
 
-    If the line is a null line, the length will remain zero regardless
-    of the length specified.
+    A null line will not be rescaled. For non-null lines with very short lengths
+    (represented by denormal floating-point values), results may be imprecise.
 
-    \sa length(), isNull()
+    \sa length(), isNull(), unitVector()
 */
 
 /*!
@@ -560,13 +579,12 @@ QDataStream &operator>>(QDataStream &stream, QLine &line)
 /*!
     Returns the length of the line.
 
-    \sa setLength()
+    \sa setLength(), isNull()
 */
 qreal QLineF::length() const
 {
-    qreal x = pt2.x() - pt1.x();
-    qreal y = pt2.y() - pt1.y();
-    return qSqrt(x*x + y*y);
+    using std::hypot;
+    return hypot(dx(), dy());
 }
 
 /*!
@@ -637,16 +655,18 @@ QLineF QLineF::fromPolar(qreal length, qreal angle)
 
 /*!
     Returns the unit vector for this line, i.e a line starting at the
-    same point as \e this line with a length of 1.0.
+    same point as \e this line with a length of 1.0, provided the line
+    is non-null.
 
-    \sa normalVector()
+    \sa normalVector(), setLength()
 */
 QLineF QLineF::unitVector() const
 {
-    qreal x = pt2.x() - pt1.x();
-    qreal y = pt2.y() - pt1.y();
+    qreal x = dx();
+    qreal y = dy();
+    using std::hypot;
+    qreal len = hypot(x, y);
 
-    qreal len = qSqrt(x*x + y*y);
     QLineF f(p1(), QPointF(pt1.x() + x/len, pt1.y() + y/len));
 
 #ifndef QT_NO_DEBUG
@@ -657,8 +677,10 @@ QLineF QLineF::unitVector() const
     return f;
 }
 
+#if QT_DEPRECATED_SINCE(5, 14)
 /*!
     \fn QLineF::IntersectType QLineF::intersect(const QLineF &line, QPointF *intersectionPoint) const
+    \obsolete Use intersects() instead
 
     Returns a value indicating whether or not \e this line intersects
     with the given \a line.
@@ -669,6 +691,23 @@ QLineF QLineF::unitVector() const
 */
 
 QLineF::IntersectType QLineF::intersect(const QLineF &l, QPointF *intersectionPoint) const
+{
+    return intersects(l, intersectionPoint);
+}
+#endif
+
+/*!
+    \fn QLineF::IntersectionType QLineF::intersects(const QLineF &line, QPointF *intersectionPoint) const
+    \since 5.14
+
+    Returns a value indicating whether or not \e this line intersects
+    with the given \a line.
+
+    The actual intersection point is extracted to \a intersectionPoint
+    (if the pointer is valid). If the lines are parallel, the
+    intersection point is undefined.
+*/
+QLineF::IntersectionType QLineF::intersects(const QLineF &l, QPointF *intersectionPoint) const
 {
     // ipmlementation is based on Graphics Gems III's "Faster Line Segment Intersection"
     const QPointF a = pt2 - pt1;
@@ -805,6 +844,7 @@ qreal QLineF::angleTo(const QLineF &l) const
         return delta_normalized;
 }
 
+#if QT_DEPRECATED_SINCE(5, 14)
 /*!
   \fn qreal QLineF::angle(const QLineF &line) const
 
@@ -837,6 +877,7 @@ qreal QLineF::angle(const QLineF &l) const
     if (cos_line >= -1.0 && cos_line <= 1.0) rad = qAcos( cos_line );
     return rad * 360 / M_2PI;
 }
+#endif
 
 
 #ifndef QT_NO_DEBUG_STREAM
