@@ -66,6 +66,8 @@
 #include "qpixmap_raster_p.h"
 #include "private/qhexstring_p.h"
 
+#include <qtgui_tracepoints_p.h>
+
 QT_BEGIN_NAMESPACE
 
 static bool qt_pixmap_thread_test()
@@ -78,7 +80,7 @@ static bool qt_pixmap_thread_test()
     if (qApp->thread() != QThread::currentThread()) {
         bool fail = false;
         if (!QGuiApplicationPrivate::platformIntegration()->hasCapability(QPlatformIntegration::ThreadedPixmaps)) {
-            printf("Lighthouse plugin does not support threaded pixmaps!\n");
+            printf("Platform plugin does not support threaded pixmaps!\n");
             fail = true;
         }
         if (fail) {
@@ -94,7 +96,7 @@ void QPixmap::doInit(int w, int h, int type)
     if ((w > 0 && h > 0) || type == QPlatformPixmap::BitmapType)
         data = QPlatformPixmap::create(w, h, (QPlatformPixmap::PixelType) type);
     else
-        data = 0;
+        data = nullptr;
 }
 
 /*!
@@ -262,7 +264,7 @@ QPixmap::QPixmap(const char * const xpm[])
 
 QPixmap::~QPixmap()
 {
-    Q_ASSERT(!data || data->ref.load() >= 1); // Catch if ref-counting changes again
+    Q_ASSERT(!data || data->ref.loadRelaxed() >= 1); // Catch if ref-counting changes again
 }
 
 /*!
@@ -402,7 +404,7 @@ QPixmap &QPixmap::operator=(const QPixmap &pixmap)
 */
 QPixmap::operator QVariant() const
 {
-    return QVariant(QVariant::Pixmap, this);
+    return QVariant(QMetaType::QPixmap, this);
 }
 
 /*!
@@ -438,7 +440,7 @@ QImage QPixmap::toImage() const
 }
 
 /*!
-    \fn QMatrix QPixmap::trueMatrix(const QTransform &matrix, int width, int height)
+    \fn QTransform QPixmap::trueMatrix(const QTransform &matrix, int width, int height)
 
     Returns the actual matrix used for transforming a pixmap with the
     given \a width, \a height and \a matrix.
@@ -458,8 +460,12 @@ QTransform QPixmap::trueMatrix(const QTransform &m, int w, int h)
     return QImage::trueMatrix(m, w, h);
 }
 
+#if QT_DEPRECATED_SINCE(5, 15)
 /*!
   \overload
+  \obsolete
+
+  Use trueMatrix(const QTransform &m, int w, int h) instead.
 
   This convenience function loads the matrix \a m into a
   QTransform and calls the overloaded function with the
@@ -469,6 +475,7 @@ QMatrix QPixmap::trueMatrix(const QMatrix &m, int w, int h)
 {
     return trueMatrix(QTransform(m), w, h).toAffine();
 }
+#endif // QT_DEPRECATED_SINCE(5, 15)
 
 
 /*!
@@ -780,7 +787,7 @@ bool QPixmap::load(const QString &fileName, const char *format, Qt::ImageConvers
 
 bool QPixmap::loadFromData(const uchar *buf, uint len, const char *format, Qt::ImageConversionFlags flags)
 {
-    if (len == 0 || buf == 0) {
+    if (len == 0 || buf == nullptr) {
         data.reset();
         return false;
     }
@@ -813,8 +820,8 @@ bool QPixmap::loadFromData(const uchar *buf, uint len, const char *format, Qt::I
     0 to obtain small compressed files, 100 for large uncompressed
     files, and -1 to use the default settings.
 
-    If \a format is 0, an image format will be chosen from \a fileName's
-    suffix.
+    If \a format is \nullptr, an image format will be chosen from
+    \a fileName's suffix.
 
     \sa {QPixmap#Reading and Writing Image Files}{Reading and Writing
     Image Files}
@@ -858,6 +865,7 @@ bool QPixmap::doImageIO(QImageWriter *writer, int quality) const
 }
 
 
+#if QT_DEPRECATED_SINCE(5, 13)
 /*!
     \obsolete
 
@@ -878,6 +886,14 @@ void QPixmap::fill(const QPaintDevice *device, const QPoint &p)
 
     Use QPainter or the fill(QColor) overload instead.
 */
+void QPixmap::fill(const QPaintDevice *device, int xofs, int yofs)
+{
+    Q_UNUSED(device)
+    Q_UNUSED(xofs)
+    Q_UNUSED(yofs)
+    qWarning("this function is deprecated, ignored");
+}
+#endif
 
 
 /*!
@@ -901,7 +917,7 @@ void QPixmap::fill(const QColor &color)
         return;
     }
 
-    if (data->ref.load() == 1) {
+    if (data->ref.loadRelaxed() == 1) {
         // detach() will also remove this pixmap from caches, so
         // it has to be called even when ref == 1.
         detach();
@@ -961,6 +977,7 @@ static void sendResizeEvents(QWidget *target)
 }
 #endif
 
+#if QT_DEPRECATED_SINCE(5, 13)
 /*!
     \obsolete
 
@@ -984,6 +1001,14 @@ QPixmap QPixmap::grabWidget(QObject *widget, const QRect &rectangle)
 
     Use QWidget::grab() instead.
 */
+QPixmap QPixmap::grabWidget(QObject *widget, int x, int y, int w, int h)
+{
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+    return grabWidget(widget, QRect(x, y, w, h));
+QT_WARNING_POP
+}
+#endif
 
 /*****************************************************************************
   QPixmap stream functions
@@ -1035,7 +1060,7 @@ QDataStream &operator>>(QDataStream &stream, QPixmap &pixmap)
 
 bool QPixmap::isDetached() const
 {
-    return data && data->ref.load() == 1;
+    return data && data->ref.loadRelaxed() == 1;
 }
 
 /*!
@@ -1126,6 +1151,8 @@ QPixmap QPixmap::scaled(const QSize& s, Qt::AspectRatioMode aspectMode, Qt::Tran
     if (newSize == size())
         return *this;
 
+    Q_TRACE_SCOPE(QPixmap_scaled, s, aspectMode, mode);
+
     QTransform wm = QTransform::fromScale((qreal)newSize.width() / width(),
                                           (qreal)newSize.height() / height());
     QPixmap pix = transformed(wm, mode);
@@ -1155,6 +1182,8 @@ QPixmap QPixmap::scaledToWidth(int w, Qt::TransformationMode mode) const
     if (w <= 0)
         return QPixmap();
 
+    Q_TRACE_SCOPE(QPixmap_scaledToWidth, w, mode);
+
     qreal factor = (qreal) w / width();
     QTransform wm = QTransform::fromScale(factor, factor);
     return transformed(wm, mode);
@@ -1183,6 +1212,8 @@ QPixmap QPixmap::scaledToHeight(int h, Qt::TransformationMode mode) const
     if (h <= 0)
         return QPixmap();
 
+    Q_TRACE_SCOPE(QPixmap_scaledToHeight, h, mode);
+
     qreal factor = (qreal) h / height();
     QTransform wm = QTransform::fromScale(factor, factor);
     return transformed(wm, mode);
@@ -1215,8 +1246,12 @@ QPixmap QPixmap::transformed(const QTransform &transform,
     return data->transformed(transform, mode);
 }
 
+#if QT_DEPRECATED_SINCE(5, 15)
 /*!
   \overload
+  \obsolete
+
+  Use transformed(const QTransform &transform, Qt::TransformationMode mode)() instead.
 
   This convenience function loads the \a matrix into a
   QTransform and calls the overloaded function.
@@ -1225,6 +1260,7 @@ QPixmap QPixmap::transformed(const QMatrix &matrix, Qt::TransformationMode mode)
 {
     return transformed(QTransform(matrix), mode);
 }
+#endif // QT_DEPRECATED_SINCE(5, 15)
 
 
 
@@ -1358,12 +1394,6 @@ QPixmap QPixmap::transformed(const QMatrix &matrix, Qt::TransformationMode mode)
     The cacheKey() function returns a number that uniquely
     identifies the contents of the QPixmap object.
 
-    The x11Info() function returns information about the configuration
-    of the X display used by the screen to which the pixmap currently
-    belongs. The x11PictureHandle() function returns the X11 Picture
-    handle of the pixmap for XRender support. Note that the two latter
-    functions are only available on x11.
-
     \endtable
 
     \section1 Pixmap Conversion
@@ -1394,9 +1424,6 @@ QPixmap QPixmap::transformed(const QMatrix &matrix, Qt::TransformationMode mode)
     function returns the actual matrix used for transforming the
     pixmap.
 
-    \note When using the native X11 graphics system, the pixmap
-    becomes invalid when the QApplication instance is destroyed.
-
     \sa QBitmap, QImage, QImageReader, QImageWriter
 */
 
@@ -1446,7 +1473,7 @@ int QPixmap::metric(PaintDeviceMetric metric) const
 */
 QPaintEngine *QPixmap::paintEngine() const
 {
-    return data ? data->paintEngine() : 0;
+    return data ? data->paintEngine() : nullptr;
 }
 
 /*!
@@ -1514,10 +1541,10 @@ void QPixmap::detach()
         rasterData->image.detach();
     }
 
-    if (data->is_cached && data->ref.load() == 1)
+    if (data->is_cached && data->ref.loadRelaxed() == 1)
         QImagePixmapCleanupHooks::executePlatformPixmapModificationHooks(data.data());
 
-    if (data->ref.load() != 1) {
+    if (data->ref.loadRelaxed() != 1) {
         *this = copy();
     }
     ++data->detach_no;
@@ -1604,6 +1631,7 @@ QPixmap QPixmap::fromImageReader(QImageReader *imageReader, Qt::ImageConversionF
     return QPixmap(data.take());
 }
 
+#if QT_DEPRECATED_SINCE(5, 13)
 /*!
     \fn QPixmap QPixmap::grabWindow(WId window, int x, int y, int
     width, int height)
@@ -1657,6 +1685,7 @@ QPixmap QPixmap::grabWindow(WId window, int x, int y, int w, int h)
              " Defaulting to primary screen.");
     return QGuiApplication::primaryScreen()->grabWindow(window, x, y, w, h);
 }
+#endif
 
 /*!
   \internal
@@ -1678,7 +1707,7 @@ QDebug operator<<(QDebug dbg, const QPixmap &r)
     } else {
         dbg << r.size() << ",depth=" << r.depth()
             << ",devicePixelRatio=" << r.devicePixelRatio()
-            << ",cacheKey=" << showbase << hex << r.cacheKey() << dec << noshowbase;
+            << ",cacheKey=" << Qt::showbase << Qt::hex << r.cacheKey() << Qt::dec << Qt::noshowbase;
     }
     dbg << ')';
     return dbg;
