@@ -265,7 +265,9 @@ QTransform::QTransform()
     , m_13(0), m_23(0), m_33(1)
     , m_type(TxNone)
     , m_dirty(TxNone)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     , d(nullptr)
+#endif
 {
 }
 
@@ -284,7 +286,9 @@ QTransform::QTransform(qreal h11, qreal h12, qreal h13,
     , m_13(h13), m_23(h23), m_33(h33)
     , m_type(TxNone)
     , m_dirty(TxProject)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     , d(nullptr)
+#endif
 {
 }
 
@@ -301,12 +305,16 @@ QTransform::QTransform(qreal h11, qreal h12, qreal h21,
     , m_13(0), m_23(0), m_33(1)
     , m_type(TxNone)
     , m_dirty(TxShear)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     , d(nullptr)
+#endif
 {
 }
 
+#if QT_DEPRECATED_SINCE(5, 15)
 /*!
     \fn QTransform::QTransform(const QMatrix &matrix)
+    \obsolete
 
     Constructs a matrix that is a copy of the given \a matrix.
     Note that the \c m13, \c m23, and \c m33 elements are set to 0, 0,
@@ -317,9 +325,12 @@ QTransform::QTransform(const QMatrix &mtx)
       m_13(0), m_23(0), m_33(1)
     , m_type(TxNone)
     , m_dirty(TxShear)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     , d(nullptr)
+#endif
 {
 }
+#endif // QT_DEPRECATED_SINCE(5, 15)
 
 /*!
     Returns the adjoint of this matrix.
@@ -795,7 +806,7 @@ bool QTransform::operator==(const QTransform &o) const
     Returns the hash value for \a key, using
     \a seed to seed the calculation.
 */
-uint qHash(const QTransform &key, uint seed) Q_DECL_NOTHROW
+uint qHash(const QTransform &key, uint seed) noexcept
 {
     QtPrivate::QHashCombine hash;
     seed = hash(seed, key.m11());
@@ -1021,7 +1032,7 @@ QTransform QTransform::operator*(const QTransform &m) const
 /*!
     Assigns the given \a matrix's values to this matrix.
 */
-QTransform & QTransform::operator=(const QTransform &matrix) Q_DECL_NOTHROW
+QTransform & QTransform::operator=(const QTransform &matrix) noexcept
 {
     affine._m11 = matrix.affine._m11;
     affine._m12 = matrix.affine._m12;
@@ -1517,8 +1528,23 @@ QRegion QTransform::map(const QRegion &r) const
         return copy;
     }
 
-    if (t == TxScale && r.rectCount() == 1)
-        return QRegion(mapRect(r.boundingRect()));
+    if (t == TxScale) {
+        QRegion res;
+        if (m11() < 0 || m22() < 0) {
+            for (const QRect &rect : r)
+                res += mapRect(QRectF(rect)).toRect();
+        } else {
+            QVarLengthArray<QRect, 32> rects;
+            rects.reserve(r.rectCount());
+            for (const QRect &rect : r) {
+                QRect nr = mapRect(QRectF(rect)).toRect();
+                if (!nr.isEmpty())
+                    rects.append(nr);
+            }
+            res.setRects(rects.constData(), rects.count());
+        }
+        return res;
+    }
 
     QPainterPath p = map(qt_regionToPath(r));
     return p.toFillPolygon(QTransform()).toPolygon();
@@ -2059,7 +2085,9 @@ void QTransform::map(int x, int y, int *tx, int *ty) const
     *ty = qRound(fy);
 }
 
+#if QT_DEPRECATED_SINCE(5, 15)
 /*!
+  \obsolete
   Returns the QTransform as an affine matrix.
 
   \warning If a perspective transformation has been specified,
@@ -2069,6 +2097,7 @@ const QMatrix &QTransform::toAffine() const
 {
     return affine;
 }
+#endif // QT_DEPRECATED_SINCE(5, 15)
 
 /*!
   Returns the transformation type of this matrix.
@@ -2132,7 +2161,7 @@ QTransform::TransformationType QTransform::type() const
 */
 QTransform::operator QVariant() const
 {
-    return QVariant(QVariant::Transform, this);
+    return QVariant(QMetaType::QTransform, this);
 }
 
 
@@ -2144,13 +2173,14 @@ QTransform::operator QVariant() const
     \sa inverted()
 */
 
+#if QT_DEPRECATED_SINCE(5, 13)
 /*!
     \fn qreal QTransform::det() const
     \obsolete
 
     Returns the matrix's determinant. Use determinant() instead.
 */
-
+#endif
 
 /*!
     \fn qreal QTransform::m11() const
