@@ -70,7 +70,7 @@ static QString pixelToPoint(qreal pixels)
 // strategies
 class QOutputStrategy {
 public:
-    QOutputStrategy() : contentStream(0), counter(1) { }
+    QOutputStrategy() : contentStream(nullptr), counter(1) { }
     virtual ~QOutputStrategy() {}
     virtual void addFile(const QString &fileName, const QString &mimeType, const QByteArray &bytes) = 0;
 
@@ -90,7 +90,7 @@ public:
         contentStream = device;
     }
 
-    virtual ~QXmlStreamStrategy()
+    ~QXmlStreamStrategy()
     {
         if (contentStream)
             contentStream->close();
@@ -240,7 +240,7 @@ void QTextOdfWriter::writeFrame(QXmlStreamWriter &writer, const QTextFrame *fram
     }
 
     QTextFrame::iterator iterator = frame->begin();
-    QTextFrame *child = 0;
+    QTextFrame *child = nullptr;
 
     int tableRow = -1;
     while (! iterator.atEnd()) {
@@ -358,7 +358,7 @@ void QTextOdfWriter::writeBlock(QXmlStreamWriter &writer, const QTextBlock &bloc
         int precedingSpaces = 0;
         int exportedIndex = 0;
         for (int i=0; i <= fragmentText.count(); ++i) {
-            QChar character = fragmentText[i];
+            QChar character = (i == fragmentText.count() ? QChar() : fragmentText.at(i));
             bool isSpace = character.unicode() == ' ';
 
             // find more than one space. -> <text:s text:c="2" />
@@ -437,7 +437,7 @@ static bool probeImageData(QIODevice *device, QImage *image, QString *mimeType,
 void QTextOdfWriter::writeInlineCharacter(QXmlStreamWriter &writer, const QTextFragment &fragment) const
 {
     writer.writeStartElement(drawNS, QString::fromLatin1("frame"));
-    if (m_strategy == 0) {
+    if (m_strategy == nullptr) {
         // don't do anything.
     }
     else if (fragment.charFormat().isImageFormat()) {
@@ -455,9 +455,9 @@ void QTextOdfWriter::writeInlineCharacter(QXmlStreamWriter &writer, const QTextF
             name.prepend(QLatin1String("qrc"));
         QUrl url = QUrl(name);
         const QVariant variant = m_document->resource(QTextDocument::ImageResource, url);
-        if (variant.type() == QVariant::Image) {
+        if (variant.userType() == QMetaType::QImage) {
             image = qvariant_cast<QImage>(variant);
-        } else if (variant.type() == QVariant::ByteArray) {
+        } else if (variant.userType() == QMetaType::QByteArray) {
             data = variant.toByteArray();
 
             QBuffer buffer(&data);
@@ -523,9 +523,7 @@ void QTextOdfWriter::writeFormats(QXmlStreamWriter &writer, const QSet<int> &for
 {
     writer.writeStartElement(officeNS, QString::fromLatin1("automatic-styles"));
     QVector<QTextFormat> allStyles = m_document->allFormats();
-    QSetIterator<int> formatId(formats);
-    while(formatId.hasNext()) {
-        int formatIndex = formatId.next();
+    for (int formatIndex : formats) {
         QTextFormat textFormat = allStyles.at(formatIndex);
         switch (textFormat.type()) {
         case QTextFormat::CharFormat:
@@ -546,10 +544,12 @@ void QTextOdfWriter::writeFormats(QXmlStreamWriter &writer, const QSet<int> &for
             else
                 writeFrameFormat(writer, textFormat.toFrameFormat(), formatIndex);
             break;
+#if QT_DEPRECATED_SINCE(5, 3)
         case QTextFormat::TableFormat:
             // this case never happens, because TableFormat is a FrameFormat
             Q_UNREACHABLE();
             break;
+#endif
         }
     }
 
@@ -936,26 +936,30 @@ void QTextOdfWriter::tableCellStyleElement(QXmlStreamWriter &writer, const int &
     if (hasBorder) {
         writer.writeAttribute(foNS, QString::fromLatin1("border"),
                               pixelToPoint(tableFormatTmp.border()) + QLatin1String(" ")
-                              + borderStyleName(tableFormatTmp.borderStyle())
-                              + QLatin1String(" #000000"));  //!! HARD-CODING color black
+                              + borderStyleName(tableFormatTmp.borderStyle()) + QLatin1String(" ")
+                              + tableFormatTmp.borderBrush().color().name(QColor::HexRgb));
     }
-    qreal padding = format.topPadding();
-    if (padding > 0 && padding == format.bottomPadding()
-        && padding == format.leftPadding() && padding == format.rightPadding()) {
+    qreal topPadding = format.topPadding();
+    qreal padding = topPadding + tableFormatTmp.cellPadding();
+    if (padding > 0 && topPadding == format.bottomPadding()
+        && topPadding == format.leftPadding() && topPadding == format.rightPadding()) {
         writer.writeAttribute(foNS, QString::fromLatin1("padding"), pixelToPoint(padding));
     }
     else {
         if (padding > 0)
             writer.writeAttribute(foNS, QString::fromLatin1("padding-top"), pixelToPoint(padding));
-        if (format.bottomPadding() > 0)
+        padding = format.bottomPadding() + tableFormatTmp.cellPadding();
+        if (padding > 0)
             writer.writeAttribute(foNS, QString::fromLatin1("padding-bottom"),
-                                  pixelToPoint(format.bottomPadding()));
-        if (format.leftPadding() > 0)
+                                  pixelToPoint(padding));
+        padding = format.leftPadding() + tableFormatTmp.cellPadding();
+        if (padding > 0)
             writer.writeAttribute(foNS, QString::fromLatin1("padding-left"),
-                                  pixelToPoint(format.leftPadding()));
-        if (format.rightPadding() > 0)
+                                  pixelToPoint(padding));
+        padding = format.rightPadding() + tableFormatTmp.cellPadding();
+        if (padding > 0)
             writer.writeAttribute(foNS, QString::fromLatin1("padding-right"),
-                                  pixelToPoint(format.rightPadding()));
+                                  pixelToPoint(padding));
     }
 
     if (format.hasProperty(QTextFormat::TextVerticalAlignment)) {
@@ -993,8 +997,8 @@ QTextOdfWriter::QTextOdfWriter(const QTextDocument &document, QIODevice *device)
     svgNS (QLatin1String("urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0")),
     m_document(&document),
     m_device(device),
-    m_strategy(0),
-    m_codec(0),
+    m_strategy(nullptr),
+    m_codec(nullptr),
     m_createArchive(true)
 {
 }
@@ -1007,7 +1011,7 @@ bool QTextOdfWriter::writeAll()
         m_strategy = new QXmlStreamStrategy(m_device);
 
     if (!m_device->isWritable() && ! m_device->open(QIODevice::WriteOnly)) {
-        qWarning("QTextOdfWriter::writeAll: the device can not be opened for writing");
+        qWarning("QTextOdfWriter::writeAll: the device cannot be opened for writing");
         return false;
     }
     QXmlStreamWriter writer(m_strategy->contentStream);
@@ -1051,7 +1055,7 @@ bool QTextOdfWriter::writeAll()
 
     // add objects for lists, frames and tables
     const QVector<QTextFormat> allFormats = m_document->allFormats();
-    const QList<int> copy = formats.toList();
+    const QList<int> copy = formats.values();
     for (auto index : copy) {
         QTextObject *object = m_document->objectForFormat(allFormats[index]);
         if (object) {
@@ -1089,7 +1093,7 @@ bool QTextOdfWriter::writeAll()
     writer.writeEndElement(); // document-content
     writer.writeEndDocument();
     delete m_strategy;
-    m_strategy = 0;
+    m_strategy = nullptr;
 
     return true;
 }
