@@ -322,8 +322,8 @@ public:
 protected:
     void timerEvent(QTimerEvent * event) override;
 
-    QMutex mutex;
-    int sweepTimerId;
+    QRecursiveMutex mutex;
+    int sweepTimerId = -1;
     //socket descriptor, data, timestamp
     QHash<int, QSocks5BindData *> store;
 };
@@ -331,8 +331,6 @@ protected:
 Q_GLOBAL_STATIC(QSocks5BindStore, socks5BindStore)
 
 QSocks5BindStore::QSocks5BindStore()
-    : mutex(QMutex::Recursive)
-    , sweepTimerId(-1)
 {
     QCoreApplication *app = QCoreApplication::instance();
     if (app && app->thread() != thread())
@@ -367,13 +365,13 @@ QSocks5BindData *QSocks5BindStore::retrieve(qintptr socketDescriptor)
     QMutexLocker lock(&mutex);
     const auto it = store.constFind(socketDescriptor);
     if (it == store.cend())
-        return 0;
+        return nullptr;
     QSocks5BindData *bindData = it.value();
     store.erase(it);
     if (bindData) {
         if (bindData->controlSocket->thread() != QThread::currentThread()) {
-            qWarning("Can not access socks5 bind data from different thread");
-            return 0;
+            qWarning("Cannot access socks5 bind data from different thread");
+            return nullptr;
         }
     } else {
         QSOCKS5_DEBUG << "__ERROR__ binddata == 0";
@@ -505,12 +503,12 @@ QSocks5SocketEnginePrivate::QSocks5SocketEnginePrivate()
     , writeNotificationEnabled(false)
     , exceptNotificationEnabled(false)
     , socketDescriptor(-1)
-    , data(0)
-    , connectData(0)
+    , data(nullptr)
+    , connectData(nullptr)
 #ifndef QT_NO_UDPSOCKET
-    , udpData(0)
+    , udpData(nullptr)
 #endif
-    , bindData(0)
+    , bindData(nullptr)
     , readNotificationActivated(false)
     , writeNotificationActivated(false)
     , readNotificationPending(false)
@@ -537,7 +535,7 @@ void QSocks5SocketEnginePrivate::initialize(Socks5Mode socks5Mode)
         udpData = new QSocks5UdpAssociateData;
         data = udpData;
         udpData->udpSocket = new QUdpSocket(q);
-#ifndef QT_NO_BEARERMANAGEMENT
+#ifndef QT_NO_BEARERMANAGEMENT // ### Qt6: Remove section
         udpData->udpSocket->setProperty("_q_networksession", q->property("_q_networksession"));
 #endif
         udpData->udpSocket->setProxy(QNetworkProxy::NoProxy);
@@ -551,7 +549,7 @@ void QSocks5SocketEnginePrivate::initialize(Socks5Mode socks5Mode)
     }
 
     data->controlSocket = new QTcpSocket(q);
-#ifndef QT_NO_BEARERMANAGEMENT
+#ifndef QT_NO_BEARERMANAGEMENT // ### Qt6: Remove section
     data->controlSocket->setProperty("_q_networksession", q->property("_q_networksession"));
 #endif
     data->controlSocket->setProxy(QNetworkProxy::NoProxy);
@@ -561,8 +559,8 @@ void QSocks5SocketEnginePrivate::initialize(Socks5Mode socks5Mode)
                      Qt::DirectConnection);
     QObject::connect(data->controlSocket, SIGNAL(bytesWritten(qint64)), q, SLOT(_q_controlSocketBytesWritten()),
                      Qt::DirectConnection);
-    QObject::connect(data->controlSocket, SIGNAL(error(QAbstractSocket::SocketError)),
-                     q, SLOT(_q_controlSocketError(QAbstractSocket::SocketError)),
+    QObject::connect(data->controlSocket, SIGNAL(errorOccurred(QAbstractSocket::SocketError)),
+                     q, SLOT(_q_controlSocketErrorOccurred(QAbstractSocket::SocketError)),
                      Qt::DirectConnection);
     QObject::connect(data->controlSocket, SIGNAL(disconnected()), q, SLOT(_q_controlSocketDisconnected()),
                      Qt::DirectConnection);
@@ -706,7 +704,7 @@ void QSocks5SocketEnginePrivate::reauthenticate()
 
     // we require authentication
     QAuthenticator auth;
-    emit q->proxyAuthenticationRequired(proxyInfo, &auth);
+    q->proxyAuthenticationRequired(proxyInfo, &auth);
 
     if (!auth.user().isEmpty() || !auth.password().isEmpty()) {
         // we have new credentials, let's try again
@@ -801,9 +799,9 @@ void QSocks5SocketEnginePrivate::sendRequestMethod()
 
     QByteArray buf;
     buf.reserve(270); // big enough for domain name;
-    buf[0] = S5_VERSION_5;
-    buf[1] = command;
-    buf[2] = 0x00;
+    buf.append(char(S5_VERSION_5));
+    buf.append(command);
+    buf.append('\0');
     if (peerName.isEmpty() && !qt_socks5_set_host_address_and_port(address, port, &buf)) {
         QSOCKS5_DEBUG << "error setting address" << address << " : " << port;
         //### set error code ....
@@ -915,7 +913,7 @@ void QSocks5SocketEnginePrivate::_q_emitPendingReadNotification()
     if (readNotificationEnabled) {
         QSOCKS5_D_DEBUG << "emitting readNotification";
         QPointer<QSocks5SocketEngine> qq = q;
-        emit q->readNotification();
+        q->readNotification();
         if (!qq)
             return;
         // check if there needs to be a new zero read notification
@@ -944,7 +942,7 @@ void QSocks5SocketEnginePrivate::_q_emitPendingWriteNotification()
     Q_Q(QSocks5SocketEngine);
     if (writeNotificationEnabled) {
         QSOCKS5_D_DEBUG << "emitting writeNotification";
-        emit q->writeNotification();
+        q->writeNotification();
     }
 }
 
@@ -964,7 +962,7 @@ void QSocks5SocketEnginePrivate::_q_emitPendingConnectionNotification()
     connectionNotificationPending = false;
     Q_Q(QSocks5SocketEngine);
     QSOCKS5_D_DEBUG << "emitting connectionNotification";
-    emit q->connectionNotification();
+    q->connectionNotification();
 }
 
 void QSocks5SocketEnginePrivate::emitConnectionNotification()
@@ -1040,11 +1038,11 @@ bool QSocks5SocketEngine::initialize(qintptr socketDescriptor, QAbstractSocket::
         d->data = d->connectData;
         d->mode = QSocks5SocketEnginePrivate::ConnectMode;
         d->data->controlSocket = bindData->controlSocket;
-        bindData->controlSocket = 0;
+        bindData->controlSocket = nullptr;
         d->data->controlSocket->setParent(this);
         d->socketProtocol = d->data->controlSocket->localAddress().protocol();
         d->data->authenticator = bindData->authenticator;
-        bindData->authenticator = 0;
+        bindData->authenticator = nullptr;
         d->localPort = bindData->localPort;
         d->localAddress = bindData->localAddress;
         d->peerPort = bindData->peerPort;
@@ -1058,7 +1056,7 @@ bool QSocks5SocketEngine::initialize(qintptr socketDescriptor, QAbstractSocket::
                          Qt::DirectConnection);
         QObject::connect(d->data->controlSocket, SIGNAL(bytesWritten(qint64)), this, SLOT(_q_controlSocketBytesWritten()),
                          Qt::DirectConnection);
-        QObject::connect(d->data->controlSocket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(_q_controlSocketError(QAbstractSocket::SocketError)),
+        QObject::connect(d->data->controlSocket, SIGNAL(errorOccurred(QAbstractSocket::SocketError)), this, SLOT(_q_controlSocketErrorOccurred(QAbstractSocket::SocketError)),
                          Qt::DirectConnection);
         QObject::connect(d->data->controlSocket, SIGNAL(disconnected()), this, SLOT(_q_controlSocketDisconnected()),
                          Qt::DirectConnection);
@@ -1233,7 +1231,7 @@ void QSocks5SocketEnginePrivate::_q_controlSocketBytesWritten()
     }
 }
 
-void QSocks5SocketEnginePrivate::_q_controlSocketError(QAbstractSocket::SocketError error)
+void QSocks5SocketEnginePrivate::_q_controlSocketErrorOccurred(QAbstractSocket::SocketError error)
 {
     QSOCKS5_D_DEBUG << "controlSocketError" << error << data->controlSocket->errorString();
 
@@ -1369,7 +1367,7 @@ bool QSocks5SocketEngine::bind(const QHostAddress &addr, quint16 port)
     QElapsedTimer stopWatch;
     stopWatch.start();
     d->data->controlSocket->connectToHost(d->proxyInfo.hostName(), d->proxyInfo.port());
-    if (!d->waitForConnected(msecs, 0) ||
+    if (!d->waitForConnected(msecs, nullptr) ||
         d->data->controlSocket->state() == QAbstractSocket::UnconnectedState) {
         // waitForConnected sets the error state and closes the socket
         QSOCKS5_Q_DEBUG << "waitForConnected to proxy server" << d->data->controlSocket->errorString();
@@ -1430,13 +1428,13 @@ int QSocks5SocketEngine::accept()
     case QSocks5SocketEnginePrivate::BindSuccess:
         QSOCKS5_Q_DEBUG << "BindSuccess adding" << d->socketDescriptor << "to the bind store";
         d->data->controlSocket->disconnect();
-        d->data->controlSocket->setParent(0);
+        d->data->controlSocket->setParent(nullptr);
         d->bindData->localAddress = d->localAddress;
         d->bindData->localPort = d->localPort;
         sd = d->socketDescriptor;
         socks5BindStore()->add(sd, d->bindData);
-        d->data = 0;
-        d->bindData = 0;
+        d->data = nullptr;
+        d->bindData = nullptr;
         d->socketDescriptor = 0;
         //### do something about this socket layer ... set it closed and an error about why ...
         // reset state and local port/address
@@ -1911,7 +1909,7 @@ QSocks5SocketEngineHandler::createSocketEngine(QAbstractSocket::SocketType socke
     // proxy type must have been resolved by now
     if (proxy.type() != QNetworkProxy::Socks5Proxy) {
         QSOCKS5_DEBUG << "not proxying";
-        return 0;
+        return nullptr;
     }
     QScopedPointer<QSocks5SocketEngine> engine(new QSocks5SocketEngine(parent));
     engine->setProxy(proxy);
@@ -1925,7 +1923,7 @@ QAbstractSocketEngine *QSocks5SocketEngineHandler::createSocketEngine(qintptr so
         QSOCKS5_DEBUG << "bind store contains" << socketDescriptor;
         return new QSocks5SocketEngine(parent);
     }
-    return 0;
+    return nullptr;
 }
 
 QT_END_NAMESPACE
