@@ -29,7 +29,7 @@
 
 #include <QtTest/QtTest>
 
-#include <qstandarditemmodel.h>
+#include <QStandardItem>
 
 class tst_QStandardItem : public QObject
 {
@@ -48,8 +48,6 @@ private slots:
     void parent();
     void insertColumn_data();
     void insertColumn();
-    void insertColumns_data();
-    void insertColumns();
     void insertRow_data();
     void insertRow();
     void insertRows_data();
@@ -202,9 +200,7 @@ void tst_QStandardItem::getSetData()
             QCOMPARE(qvariant_cast<QSize>(item.data(Qt::SizeHintRole)), sizeHint);
             QCOMPARE(qvariant_cast<QFont>(item.data(Qt::FontRole)), font);
             QCOMPARE(qvariant_cast<int>(item.data(Qt::TextAlignmentRole)), int(textAlignment));
-            QCOMPARE(qvariant_cast<QBrush>(item.data(Qt::BackgroundColorRole)), QBrush(backgroundColor));
             QCOMPARE(qvariant_cast<QBrush>(item.data(Qt::BackgroundRole)), QBrush(backgroundColor));
-            QCOMPARE(qvariant_cast<QBrush>(item.data(Qt::TextColorRole)), QBrush(textColor));
             QCOMPARE(qvariant_cast<QBrush>(item.data(Qt::ForegroundRole)), QBrush(textColor));
             QCOMPARE(qvariant_cast<int>(item.data(Qt::CheckStateRole)), int(checkState));
             QCOMPARE(qvariant_cast<QString>(item.data(Qt::AccessibleTextRole)), accessibleText);
@@ -236,9 +232,7 @@ void tst_QStandardItem::getSetData()
         QCOMPARE(item.data(Qt::SizeHintRole), QVariant());
         QCOMPARE(item.data(Qt::FontRole), QVariant());
         QCOMPARE(item.data(Qt::TextAlignmentRole), QVariant());
-        QCOMPARE(item.data(Qt::BackgroundColorRole), QVariant());
         QCOMPARE(item.data(Qt::BackgroundRole), QVariant());
-        QCOMPARE(item.data(Qt::TextColorRole), QVariant());
         QCOMPARE(item.data(Qt::ForegroundRole), QVariant());
         QCOMPARE(item.data(Qt::CheckStateRole), QVariant());
         QCOMPARE(item.data(Qt::AccessibleTextRole), QVariant());
@@ -315,12 +309,17 @@ void tst_QStandardItem::getSetFlags()
     item.setCheckable(true);
     QCOMPARE(item.checkState(), Qt::Checked);
 
+#if QT_DEPRECATED_SINCE(5, 6)
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
     // deprecated API
     item.setTristate(true);
     QVERIFY(item.isTristate());
     QVERIFY(item.flags() & Qt::ItemIsTristate);
     item.setTristate(false);
     QVERIFY(!(item.flags() & Qt::ItemIsTristate));
+QT_WARNING_POP
+#endif
 }
 
 void tst_QStandardItem::getSetRowAndColumnCount()
@@ -384,7 +383,7 @@ void tst_QStandardItem::getSetChild()
     QStandardItem item(rows, columns);
     bool shouldHaveChildren = (rows > 0) && (columns > 0);
     QCOMPARE(item.hasChildren(), shouldHaveChildren);
-    QCOMPARE(item.child(row, column), static_cast<QStandardItem*>(0));
+    QCOMPARE(item.child(row, column), nullptr);
 
     QStandardItem *child = new QStandardItem;
     item.setChild(row, column, child);
@@ -401,11 +400,11 @@ void tst_QStandardItem::getSetChild()
         QCOMPARE(item.child(row, column), anotherChild);
         QCOMPARE(anotherChild->row(), row);
         QCOMPARE(anotherChild->column(), column);
-        item.setChild(row, column, 0);
+        item.setChild(row, column, nullptr);
     } else {
         delete child;
     }
-    QCOMPARE(item.child(row, column), static_cast<QStandardItem*>(0));
+    QCOMPARE(item.child(row, column), nullptr);
 }
 
 void tst_QStandardItem::parent()
@@ -413,7 +412,7 @@ void tst_QStandardItem::parent()
     {
         QStandardItem item;
         QStandardItem *child = new QStandardItem;
-        QCOMPARE(child->parent(), static_cast<QStandardItem*>(0));
+        QCOMPARE(child->parent(), nullptr);
         item.setChild(0, 0, child);
         QCOMPARE(child->parent(), &item);
 
@@ -427,7 +426,7 @@ void tst_QStandardItem::parent()
         QStandardItem *item = new QStandardItem;
         model.appendRow(item);
         // parent of a top-level item should be 0
-        QCOMPARE(item->parent(), static_cast<QStandardItem*>(0));
+        QCOMPARE(item->parent(), nullptr);
     }
 }
 
@@ -487,7 +486,7 @@ void tst_QStandardItem::insertColumn()
         for (int i = 0; i < count; ++i)
             QCOMPARE(item.child(i, column), columnItems.at(i));
         for (int i = count; i < item.rowCount(); ++i)
-            QCOMPARE(item.child(i, column), static_cast<QStandardItem*>(0));
+            QCOMPARE(item.child(i, column), nullptr);
     } else {
         QCOMPARE(item.columnCount(), columns);
         QCOMPARE(item.rowCount(), rows);
@@ -495,14 +494,6 @@ void tst_QStandardItem::insertColumn()
     }
 }
 
-void tst_QStandardItem::insertColumns_data()
-{
-}
-
-void tst_QStandardItem::insertColumns()
-{
-}
-
 void tst_QStandardItem::insertRow_data()
 {
     QTest::addColumn<int>("rows");
@@ -559,7 +550,7 @@ void tst_QStandardItem::insertRow()
         for (int i = 0; i < count; ++i)
             QCOMPARE(item.child(row, i), rowItems.at(i));
         for (int i = count; i < item.columnCount(); ++i)
-            QCOMPARE(item.child(row, i), static_cast<QStandardItem*>(0));
+            QCOMPARE(item.child(row, i), nullptr);
     } else {
         QCOMPARE(item.columnCount(), columns);
         QCOMPARE(item.rowCount(), rows);
@@ -587,9 +578,8 @@ void tst_QStandardItem::insertRows()
     QStandardItem item(rows, columns);
 
     QList<QStandardItem*> items;
-    for (int i = 0; i < insertCount; ++i) {
+    for (int i = 0; i < insertCount; ++i)
         items.append(new QStandardItem());
-    }
     item.insertRows(insertAt, items);
 
     QCOMPARE(item.rowCount(), rows + insertCount);
@@ -661,7 +651,7 @@ void tst_QStandardItem::appendColumn()
     for (int i = 0; i < count; ++i)
         QCOMPARE(item.child(i, columns), columnItems.at(i));
     for (int i = count; i < item.rowCount(); ++i)
-        QCOMPARE(item.child(i, columns), static_cast<QStandardItem*>(0));
+        QCOMPARE(item.child(i, columns), nullptr);
 
     // make sure original children remained unchanged
     for (int i = 0; i < rows; ++i) {
@@ -736,7 +726,7 @@ void tst_QStandardItem::appendRow()
     for (int i = 0; i < count; ++i)
         QCOMPARE(item.child(rows, i), rowItems.at(i));
     for (int i = count; i < item.columnCount(); ++i)
-        QCOMPARE(item.child(rows, i), static_cast<QStandardItem*>(0));
+        QCOMPARE(item.child(rows, i), nullptr);
 
     // make sure original children remained unchanged
     for (int i = 0; i < rows; ++i) {
@@ -755,7 +745,7 @@ void tst_QStandardItem::takeChild()
 
     for (int i = 0; i < item.rowCount(); ++i) {
         QCOMPARE(item.takeChild(i), itemList.at(i));
-        QCOMPARE(item.takeChild(0, 0), static_cast<QStandardItem*>(0));
+        QCOMPARE(item.takeChild(0, 0), nullptr);
         for (int j = i + 1; j < item.rowCount(); ++j)
             QCOMPARE(item.child(j), itemList.at(j));
     }
@@ -940,7 +930,7 @@ void tst_QStandardItem::deleteItem()
         for (int j = 0; j < model.columnCount(); ++j) {
             QStandardItem *item = model.item(i, j);
             delete item;
-            QCOMPARE(model.item(i, j), static_cast<QStandardItem*>(0));
+            QCOMPARE(model.item(i, j), nullptr);
         }
     }
 }
@@ -997,9 +987,9 @@ void tst_QStandardItem::sortChildren()
         item->appendRow(two);
 
         QSignalSpy layoutAboutToBeChangedSpy(
-            model, SIGNAL(layoutAboutToBeChanged()));
+            model, &QAbstractItemModel::layoutAboutToBeChanged);
         QSignalSpy layoutChangedSpy(
-            model, SIGNAL(layoutChanged()));
+            model, &QAbstractItemModel::layoutChanged);
 
         one->sortChildren(0, Qt::DescendingOrder);
         // verify sorted
@@ -1042,19 +1032,16 @@ void tst_QStandardItem::sortChildren()
 class CustomItem : public QStandardItem
 {
 public:
-    CustomItem(const QString &text) : QStandardItem(text) { }
-    CustomItem() { }
-    virtual ~CustomItem() { }
+    using QStandardItem::QStandardItem;
 
-    virtual int type() const { return QStandardItem::UserType + 1; }
+    int type() const override { return QStandardItem::UserType + 1; }
 
-    virtual QStandardItem *clone() const { return QStandardItem::clone(); }
-
-    void emitDataChanged() { QStandardItem::emitDataChanged(); }
-
-    virtual bool operator<(const QStandardItem &other) const {
+    bool operator<(const QStandardItem &other) const override {
         return text().length() < other.text().length();
     }
+
+    using QStandardItem::clone;
+    using QStandardItem::emitDataChanged;
 };
 
 Q_DECLARE_METATYPE(QStandardItem*)
@@ -1074,11 +1061,11 @@ void tst_QStandardItem::subclassing()
     QStandardItemModel model;
     model.appendRow(item);
 
-    QSignalSpy itemChangedSpy(&model, SIGNAL(itemChanged(QStandardItem*)));
+    QSignalSpy itemChangedSpy(&model, &QStandardItemModel::itemChanged);
     item->emitDataChanged();
     QCOMPARE(itemChangedSpy.count(), 1);
     QCOMPARE(itemChangedSpy.at(0).count(), 1);
-    QCOMPARE(qvariant_cast<QStandardItem*>(itemChangedSpy.at(0).at(0)), (QStandardItem*)item);
+    QCOMPARE(qvariant_cast<QStandardItem*>(itemChangedSpy.at(0).at(0)), item);
 
     CustomItem *child0 = new CustomItem("cc");
     CustomItem *child1 = new CustomItem("bbb");
@@ -1087,9 +1074,9 @@ void tst_QStandardItem::subclassing()
     item->appendRow(child1);
     item->appendRow(child2);
     item->sortChildren(0);
-    QCOMPARE(item->child(0), (QStandardItem*)child2);
-    QCOMPARE(item->child(1), (QStandardItem*)child0);
-    QCOMPARE(item->child(2), (QStandardItem*)child1);
+    QCOMPARE(item->child(0), child2);
+    QCOMPARE(item->child(1), child0);
+    QCOMPARE(item->child(2), child1);
 }
 
 void tst_QStandardItem::lessThan()
